# PNL 70 Traffico

# DATI
param n;				# Numero di nodi del grafo
set N := 1..n;			# Set di nodi del grafo
set A within N cross N;	# Set di archi del grafo
param tb {A};			# Tempo base
param k {A};			# Coefficiente di proporz.
set C within N cross N; # Coppie O/D
param r {C};			# Traffico per ogni coppia

# VARIABILI
# Flusso di veicoli su ogni arco (i,j) per ogni coppia (o,d)
var x {A,C} >=0;
# Tempo di percorrenza su ogni arco
var t {(i,j) in A} = tb[i,j] + k[i,j] * (sum {(o,d) in C} x[i,j,o,d])^2;

# VINCOLI
# Vincoli di flusso per ogni cammino (o,d)
subject to Flowout {(o,d) in C}:
  sum {(o,j) in A} x[o,j,o,d] - sum {(j,o) in A} x[j,o,o,d] = r[o,d];
subject to Flowin {(o,d) in C}:
  sum {(d,j) in A} x[d,j,o,d] - sum {(j,d) in A} x[j,d,o,d] = -r[o,d];
subject to Flowcons {(o,d) in C, i in N: (i<>o) and (i<>d)}:
  sum {(i,j) in A} x[i,j,o,d] - sum {(j,i) in A} x[j,i,o,d] = 0;

# OBIETTIVO
minimize z: sum {(i,j) in A, (o,d) in C} t[i,j] * x[i,j,o,d];
  
#############################
data;
param n := 5;

param: A:  tb        k  :=
1 2        20       0.1  
1 4        14       0.1          
1 5         7       0.2  
2 1        20       0.1  
2 3        22       0.1  
2 5        15       0.2  
3 2        22       0.1  
3 4        15       0.1  
3 5        10       0.2    
4 1        14       0.1    
4 3        15       0.1  
4 5        10       0.2  
5 1         7       0.2  
5 2        15       0.2  
5 3        10       0.2  
5 4        10       0.2;

param: C:    r :=
      1 3   60 
      2 4   80 
      3 1  120 
      4 2   50;

end;
